<%
	//Constructor ResTree 
	function ResTree()
	{
		this.res = new ActiveXObject("ResTree.Client");
		this.res.InitClient();
		this.path = "";
		this.currentChild ="";
	}

	// Function ResTree.expandName
	// Creates a fully quailfied path
	// Parameters:
	//   name: partial resource name
	ResTree.prototype.expandName = function(name)
	{
		return (this.path == "") ? name : this.path + '.' + name;
	}
	
	// Function ResTree.valueType
	// Gets the value type of a named resource
	// parameters:
	// name: Resource name (partial path)
	ResTree.prototype.valueType = function(name)
	{
		var ret = "N/A";
		switch (this.res.GetResourceValueType(this.expandName(name)))
		{
		case 1: // bool?
			ret = "bool";
			break;
		case 2: // int?
			ret = "int";
			break;
		case 3: // float?
			ret = "float";
			break;
		case 4: // string?
		case 7: // unicode string?
			ret = "string";
			break;
		case 8: // binary?
			ret = "binary";
			break;
		default:
			ret = "N/A";
			break;
		}
		return ret;
	}

	// Function ResTree.getResourceValue
	// Gets the value of a named resource
	// parameters:
	// name: Resource name (partial path)
	ResTree.prototype.getResourceValue = function(name)
	{
		var ret;
		switch (this.res.GetResourceValueType(this.expandName(name)))
		{
		case 1: // bool?
				ret = this.res.GetBoolValue(this.expandName(name)) == 1 ? true : false;
			break;
		case 2: // int?
			ret = this.res.GetIntValue(this.expandName(name));
			break;
		case 3: // float?
			ret = this.res.GetDoubleValue(this.expandName(name))
			break;
		case 4: // string?
		case 7: // unicode string?
			ret = this.res.GetTextValue(this.expandName(name));
			break;
		case 8: // binary?
			ret = "binary";
			break;
		default:
			ret = "FAILED";
		}
		return ret;
	}

	// Function ResTree.setResourceValue
	// Sets the value of a named resource
	// parameters:
	// name: Resource name (partial path)
	// value: Value to assign to resource
	ResTree.prototype.setResourceValue = function(name, value)
	{
		switch (this.res.GetResourceValueType(this.expandName(name)))
		{
		case 1: // bool?
			this.res.SetBoolValue(this.expandName(name), (value == 1)||(value == "true")||(value == "1")||(value=="on") ? 1 : 0);
			break;
		case 2: // int?
			this.res.SetIntValue(this.expandName(name), parseInt(value, 10));
			break;
		case 3: // float?
			this.res.SetDoubleValue(this.expandName(name), value);
			break;
		case 4: // string?
		case 7: // unicode string?
			this.res.SetTextValue(this.expandName(name), value);
			break;
		case 8: // binary?
			// How
			break;
		}
	}

	// Function ResTree.setResourceValueWait
	// Sets the value of a named resource and waits for completion
	// parameters:
	// name: Resource name (partial path)
	// value: Value to assign to resource
	ResTree.prototype.setResourceValueWait = function(name, value)
	{
		switch (this.res.GetResourceValueType(this.expandName(name)))
		{
		case 1: // bool?
			this.res.SetBoolValueWait(this.expandName(name), (value == 1)||(value == "true")||(value == "1")||(value=="on") ? 1 : 0);
			break;
		case 2: // int?
			this.res.SetIntValueWait(this.expandName(name), parseInt(value, 10));
			break;
		case 3: // float?
			this.res.SetDoubleValueWait(this.expandName(name), value);
			break;
		case 4: // string?
		case 7: // unicode string?
			this.res.SetTextValueWait(this.expandName(name), value);
			break;
		case 8: // binary?
			// How
			break;
		}
	}

	// Function ResTree.getFirst
	// Returns the first child under "ResTree.path"
	// parameters: none
	// Returns: Name of first child
	ResTree.prototype.getFirst = function()
	{
		this.currentChild = this.res.GetFirstChild(this.path);
		return this.currentChild;
	}

	// Function ResTree.getNext
	// Returns the next child under "ResTree.path"
	// parameters: none
	// Returns: Name of next child; empty string if no child found
	ResTree.prototype.getNext = function()
	{
		return this.res.GetNextChild();
	}

	// Function ResTree.setCurrent
	// Resets the current child under "ResTree.path"
	// parameters: current child resource name
	ResTree.prototype.setCurrent = function( name )
	{
		return this.res.SetCurrentChild(this.expandName(name));
	}

	// Function ResTree.sleep
	// Calls CE Sleep
	// parameters: Number of milliseconds to sleep
	ResTree.prototype.sleep = function( millisec )
	{
		return this.res.Sleep( millisec );
	}

/************ GLOBAL INSTANCES**************/
	var restree = new ResTree();
%>
