<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!-- Main template -->
<xsl:template match="/">
	<xsl:processing-instruction name="xml-stylesheet">
		type="text/css" href="#resultsCSS"
	</xsl:processing-instruction>
	<HTML>
	<HEAD><TITLE>Results from production</TITLE></HEAD>
	<BODY class="cameraResults">
		<xsl:apply-templates/>
	</BODY>
	</HTML>

<style id="resultsCSS">
style
{
	display: none;
}
.cameraResults
{
	font-family: tahoma;
	font-size: 10pt;
	font-style: normal;
	font-weight: normal;

	background-color: transparent;
	color: black;

	border: none;
	margin: 16px 16px;
	padding: 0px;
}


.section
{
	font-size: 12pt;

	margin: 16px 8px;
	padding: 20px;
	display: block;
}



.table
{
	border: 2px solid black;
	margin: 10px;
}
.tableRow
{
	border: 0.1px solid black;
}
.tableResult
{
	display: table-cell;
	border: 1px solid black;
	padding: 2px 3px
}

.result
{
	background: #e0e0ff;
	display: block;
}

.limits
{
	font-size: 12pt;
	display: block;
}
.limitResultTrue
{	
	background: #a0f8a0;
}
.limitResultFalse
{
	background: #f8a0a0;
}
	
.limitTable
{
	border: 1px solid black;
	margin: 10px;
}

.limitTableRow
{
}


.limitTableResult
{
	border: 0.1px solid black;
	padding: 2px 3px
}
.limitTableResultTrue
{	
	background: #a0f8a0;
	border: 1px solid black;
	padding: 2px 3px
}
.limitTableResultFalse
{
	background: #f8a0a0;
	border: 1px solid black;
	padding: 2px 3px
}
.style
{
	display: none;
}
</style>
</xsl:template>


<!-- Camera result template -->
<xsl:template match="cameraResults">
	<H1>Results from production</H1>
	<xsl:apply-templates/>
</xsl:template>

<!-- Section template -->
<xsl:template match="section">
	<H2>Section: <xsl:value-of select="@name"/></H2>
	<table>
		<tr>
		<td width="20"></td>
		<td><xsl:apply-templates/></td>
		</tr>
	</table>
</xsl:template>

<!-- Subsection template -->
<xsl:template match="subsection">
	<it><H3>Subsection: <xsl:value-of select="@name"/></H3></it>
	<table>
		<tr>
		<td width="20"></td>
		<td><xsl:apply-templates/></td>
		</tr>
	</table>
</xsl:template>

<!-- Section result -->
<xsl:template match="result">
	<SPAN class="result">
		<b><xsl:value-of select="@name"/>: </b> <xsl:value-of select="."/>
	</SPAN>
</xsl:template>


<!-- Section table-->
<xsl:template match="table">
	<H4><xsl:value-of select="@name"/></H4>
	<TABLE class="table">
	<TR>
	<xsl:for-each select="tableRow[position()=1]/tableResult">
		<TD class="tableResult"><b><xsl:value-of select="@name"/></b></TD>
	</xsl:for-each>
	</TR>
	<xsl:apply-templates/>
	</TABLE>
</xsl:template>

<!-- Section tableRow-->
<xsl:template match="tableRow">
	<TR class="tableRow">
	<xsl:apply-templates/>
	</TR>
</xsl:template>

<!-- Section tableResult-->
<xsl:template match="tableResult">
	<TD class="tableResult">
	<xsl:apply-templates/>
	
	</TD>
</xsl:template>

<!-- Section limits -->
<xsl:template match="limits">
	<h3><xsl:value-of select="@name"/></h3>
	<xsl:apply-templates/>
</xsl:template>

<!-- Section limitResult -->
<xsl:template match="limitResult">
	<xsl:choose>
		<xsl:when test="@valid[. = 'true']">
			<SPAN class="limitResultTrue">
				<b><xsl:value-of select="@name"/>: </b>
				<xsl:value-of select="."/>
				(<xsl:if test="@min">
					min: <xsl:value-of select="@min"/>
				</xsl:if>
				<xsl:if test="@max">
					max: <xsl:value-of select="@max"/>
				</xsl:if>)
			</SPAN>
		</xsl:when>
		<xsl:when test="@valid[. = 'false']">
			<SPAN class="limitResultFalse">
				<b><xsl:value-of select="@name"/>: </b>
				<xsl:value-of select="."/>
				(<xsl:if test="@min">
					min: <xsl:value-of select="@min"/>
				</xsl:if>
				<xsl:if test="@max">
					max: <xsl:value-of select="@max"/>
				</xsl:if>)
			</SPAN>
		</xsl:when>
		<xsl:otherwise>Error</xsl:otherwise>
	</xsl:choose>
	<BR/>
</xsl:template>

<!-- Section limitTable -->
<xsl:template match="limitTable">
	<H4><xsl:value-of select="@name"/></H4>
	<TABLE class="table">
	<TR class="tableRow">
	<xsl:for-each select="limitTableRow[position()=1]/limitTableResult">
		<TD class="tableResult"><b><xsl:value-of select="@name"/></b></TD>
	</xsl:for-each>
	</TR>
	<xsl:apply-templates/>
	</TABLE>
</xsl:template>

<!-- Section lmitTableRow-->
<xsl:template match="limitTableRow">
	<TR class="tableRow">
	<xsl:apply-templates/>
	</TR>
</xsl:template>

<!-- Section limitTableResult-->
<xsl:template match="limitTableResult">
	<xsl:choose>
		<xsl:when test="@valid[. = 'true']">
			<TD class="limitTableResultTrue">
				<xsl:value-of select="."/>
				<xsl:if test="boolean(@min)+boolean(@max)">
				(<xsl:if test="@min">
					min: <xsl:value-of select="@min"/>
				</xsl:if>
				<xsl:if test="@max">
					max: <xsl:value-of select="@max"/>
				</xsl:if>)
				</xsl:if>
			</TD>
		</xsl:when>
		<xsl:when test="@valid[. = 'false']">
			<TD class="limitTableResultFalse">
				<xsl:value-of select="."/>
				(<xsl:if test="@min">
					min: <xsl:value-of select="@min"/>
				</xsl:if>
				<xsl:if test="@max">
					max: <xsl:value-of select="@max"/>
				</xsl:if>)
			</TD>
		</xsl:when>
		<xsl:otherwise>
			<TD class="tableResult">
				<xsl:value-of select="."/>
			</TD>
		</xsl:otherwise>
	</xsl:choose>

</xsl:template>


<!-- Section style (hide style node) -->
<xsl:template match="style">
</xsl:template>

</xsl:stylesheet>
